Change Log — docp-docling - v1.0.1 Documentation

# Change Log

- 1.0.1 - Startup checks fix. by j_berendt at 2026-01-25 16:43:00

      Fix:
      - Updated the startup checks to simply print an error message rather than
        raise a RuntimeError.
        - The raised error causes the documentation build to fail for docp-loaders
          as the docling config key will *never* be populated on a new
          installation.

      Released: 2026-01-25

- 1.0.0 - Production release for v1.0.0.dev1. by j_berendt at 2026-01-25 15:51:14

      Released: 2026-01-25

- 1.0.0.dev1 - Initial PDF to Markdown/HTML implementation complete. by j_berendt at 2025-12-19 16:13:03

      ** Development release for docp-* library development. **

      Available PDF converters:
      - PDF --> Markdown
      - PDF --> HTML

      Testing:
      - All tests complete successfully with 100% code coverage.
      - Pylintr runs successfully with all modules reporting 10/10.

      Released: n/a

- 1.0.0.dev1 - Initial project commit. by j_berendt at 2025-12-18 16:06:08